==> bookmarkbridge_0.72.orig.tar.gz: bookmarkbridge-0.72/bookmarkbridge/dlgexcept.cpp <==
/***************************************************************************
                       dlgexcept.cpp  -  description
                             -------------------
    begin                : Sat Feb 08 2003
    copyright            : (C) 2002 by Ken Schenke
    email                : kenschenke at yahoo dot com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   In addition, as a special exception, Ken Schenke gives permission to  *
 *   link the code of this program with the Qt non-commercial edition (or  *
 *   with modified versions of the Qt non-commercial edition that use the  *
 *   same license as the Qt non-commercial edition, and distribute linked  *
 *   combinations including the two.  You must obey the GNU General Public *
 *   License in all respects for all of the code used other than the Qt    *
 *   Non-Commercial edition.  If you modify this file, you may extend this *
 *   exception to your version of the file, but you are not obligated to   *
 *   do so.  If you do not wish to do so, delete this exception statement  *
 *   from your version.                                                    *
 *                                                                         *
 ***************************************************************************/

#include "dlgexcept.h"

#include <qlabel.h>
#include <qstring.h>
#include <qpushbutton.h>
#include <qpixmap.h>
#include <qmessagebox.h>

/***************************************************************************
 *                                                                         *
 *   DlgExcept::DlgExcept()                                                *
 *                                                                         *
 *   Parameters:                                                           *
 *      const BkException &e                                               *
 *      QWidget *parent                                                    *
 *      const char *name                                                   *
 *      bool modal                                                         *
 *      WFlags f                                                           *
 *   Return:                                                               *
 *      None                                                               *
 *   Description:                                                          *
 *      Class constructor                                                  *
 *                                                                         *
 ***************************************************************************/

DlgExcept::DlgExcept(
	const BkException &e,
	QWidget *parent,
	const char *name,
	bool modal,
	WFlags f)
	: DlgExceptBase(parent, name, modal, f)
{
	labelMsg->setText(e.msg());

	QString detailmsg;
	detailmsg.sprintf("The error occured on line %d of %s",
		e.line(), e.file());
	labelDetails->setText(detailmsg);
	labelDetails->hide();

	pixmapIcon->setPixmap(
		QMessageBox::standardIcon(QMessageBox::Critical, Qt::WindowsStyle));
}

void DlgExcept::buttonDetailsClicked(void)
{
	buttonDetails->hide();
	labelDetails->show();
}

==> bookmarkbridge_0.76.orig.tar.gz: bookmarkbridge-0.76/bookmarkbridge/dlgexcept.cpp <==
/***************************************************************************
                       dlgexcept.cpp  -  description
                             -------------------
    begin                : Sat Feb 08 2003
    copyright            : (C) 2002 by Ken Schenke
    email                : kschenke at users dot sourceforge dot net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA         *
 *   02110-1301, USA                                                       *
 *                                                                         *
 ***************************************************************************/

#include "dlgexcept.h"

#include <QLabel>
#include <QString>
#include <QPixmap>
#include <QMessageBox>

/***************************************************************************
 *                                                                         *
 *   DlgExcept::DlgExcept()                                                *
 *                                                                         *
 *   Parameters:                                                           *
 *      const BkException &e                                               *
 *      QWidget *parent                                                    *
 *   Return:                                                               *
 *      None                                                               *
 *   Description:                                                          *
 *      Class constructor                                                  *
 *                                                                         *
 ***************************************************************************/

DlgExcept::DlgExcept(const BkException &e, QWidget *parent) :
	QDialog(parent)
{
	setupUi(this);

	labelMsg->setWordWrap( true );
	labelMsg->setText(e.msg());

	QString detailmsg;
	detailmsg.sprintf("The error occured on line %d of ", e.line());
	detailmsg += e.file();
	labelDetails->setText(detailmsg);
	labelDetails->hide();

	pixmapIcon->setPixmap(QMessageBox::standardIcon(QMessageBox::Critical));
}

/***************************************************************************
 *                                                                         *
 *   DlgExcept::on_buttonDetails_clicked()                                 *
 *                                                                         *
 *   Parameters:                                                           *
 *      None                                                               *
 *   Return:                                                               *
 *      None                                                               *
 *   Description:                                                          *
 *      Called when the user clicks on the Details button.                 *
 *                                                                         *
 ***************************************************************************/

void DlgExcept::on_buttonDetails_clicked(void)
{
	buttonDetails->hide();
	labelDetails->show();
}
